CropAspectRatio enum
Crop aspect ratio modes
Values
- square → const CropAspectRatio
-
1:1 square crop (default) - crops to the largest square that fits
const CropAspectRatio(0) - original → const CropAspectRatio
-
Keep original aspect ratio - scales proportionally
const CropAspectRatio(1) - custom → const CropAspectRatio
-
Custom aspect ratio - use
aspectRatioWidthandaspectRatioHeightconst CropAspectRatio(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CropAspectRatio> - A constant List of the values in this enum, in order of their declaration.